@@ -33,6 +33,8 @@ class ENV_VARIABLES:
     HOPSWORKS_VERSION_ENV_VAR = "HOPSWORKS_VERSION"
     HADOOP_VERSION_ENV_VAR = "HADOOP_VERSION"
     HADOOP_USER_NAME_ENV_VAR = "HADOOP_USER_NAME"
+    HADOOP_HOME = "HADOOP_HOME"
+    HADOOP_CLASSPATH_GLOB = "HADOOP_CLASSPATH_GLOB"
     HDFS_USER_ENV_VAR = "HDFS_USER"
     HOPSWORKS_USER_ENV_VAR = "HOPSWORKS_USER"
     PATH_ENV_VAR = "PATH"
@@ -44,11 +46,13 @@ class ENV_VARIABLES:
     API_KEY_ENV_VAR = "API_KEY"
     REGION_NAME_ENV_VAR = "REGION_NAME"
     FLINK_CONF_DIR = "FLINK_CONF_DIR"
+    FLINK_LIB_DIR = "FLINK_LIB_DIR"
     REQUESTS_VERIFY = "REQUESTS_VERIFY"
     REQUESTS_VERIFY_ENV_VAR = "REQUESTS_VERIFY"
     DOMAIN_CA_TRUSTSTORE_ENV_VAR = "DOMAIN_CA_TRUSTSTORE"
     DOMAIN_CA_TRUSTSTORE_PEM_ENV_VAR = "DOMAIN_CA_TRUSTSTORE_PEM"
     SECRETS_DIR_ENV_VAR = "SECRETS_DIR"
+    SPARK_IS_DRIVER = "IS_HOPS_DRIVER"
 
 
 class KAFKA_SSL_CONFIG:
@@ -223,21 +227,8 @@ class FEATURE_STORE:
         TRAINING_DATASET_IMAGE_FORMAT,
         TRAINING_DATASET_PETASTORM_FORMAT
     ]
-    CLUSTERING_ANALYSIS_INPUT_COLUMN = "featurestore_feature_clustering_analysis_input_col"
-    CLUSTERING_ANALYSIS_OUTPUT_COLUMN = "featurestore_feature_clustering_analysis_output_col"
-    CLUSTERING_ANALYSIS_PCA_COLUMN = "featurestore_feature_clustering_analysis_pca_col"
-    CLUSTERING_ANALYSIS_FEATURES_COLUMN = "features"
-    CLUSTERING_ANALYSIS_CLUSTERS_OUTPUT_COLUMN = "clusters"
-    CLUSTERING_ANALYSIS_CLUSTERS_COLUMN = "featurestore_feature_clustering_analysis_pca_col"
-    CLUSTERING_ANALYSIS_ARRAY_COLUMN = "array"
-    CLUSTERING_ANALYSIS_SAMPLE_SIZE = 50
     FEATURE_GROUP_INSERT_APPEND_MODE = "append"
     FEATURE_GROUP_INSERT_OVERWRITE_MODE = "overwrite"
-    DESCRIPTIVE_STATS_SUMMARY_COL= "summary"
-    DESCRIPTIVE_STATS_METRIC_NAME_COL= "metricName"
-    DESCRIPTIVE_STATS_VALUE_COL= "value"
-    HISTOGRAM_FREQUENCY = "frequency"
-    HISTOGRAM_FEATURE = "feature"
     FEATURESTORE_SUFFIX =  "_featurestore"
     TRAINING_DATASETS_SUFFIX =  "_Training_Datasets"
     TRAINING_DATASET_TF_RECORD_SCHEMA_FILE_NAME = "tf_record_schema.txt"
@@ -338,7 +329,6 @@ class REST_CONFIG:
     JSON_FEATURESTORE_SETTINGS_CACHED_FEATUREGROUP_DTO_TYPE = "cachedFeaturegroupDtoType"
     JSON_FEATURESTORE_SETTINGS_EXTERNAL_TRAINING_DATASET_TYPE = "externalTrainingDatasetType"
     JSON_FEATURESTORE_SETTINGS_FEATURESTORE_REGEX = "featurestoreRegex"
-    JSON_FEATURESTORE_SETTINGS_MAX_CORRELATIONS = "featurestoreStatisticsMaxCorrelations"
     JSON_FEATURESTORE_SETTINGS_HOPSFS_CONNECTOR_DTO_TYPE = "hopsfsConnectorDtoType"
     JSON_FEATURESTORE_SETTINGS_HOPSFS_CONNECTOR_TYPE = "hopsfsConnectorType"
     JSON_FEATURESTORE_SETTINGS_HOPSFS_TRAINING_DATASET_TYPE = "hopsfsTrainingDatasetType"
@@ -385,22 +375,13 @@ class REST_CONFIG:
     JSON_FEATUREGROUP_DESCRIPTION = "description"
     JSON_FEATUREGROUP_CREATED = "created"
     JSON_FEATUREGROUP_CREATOR = "creator"
-    JSON_FEATUREGROUP_FEATURE_CORRELATION = "featureCorrelationMatrix"
-    JSON_FEATUREGROUP_DESC_STATS = "descriptiveStatistics"
-    JSON_FEATUREGROUP_UPDATE_STATS = "updateStats"
-    JSON_FEATUREGROUP_FEATURES_HISTOGRAM = "featuresHistogram"
-    JSON_FEATUREGROUP_FEATURES_CLUSTERS = "clusterAnalysis"
     JSON_FEATUREGROUPS = "featuregroups"
     JSON_FEATUREGROUP_ONLINE = "onlineEnabled"
     JSON_FEATUREGROUP_HUDI = "hudiEnabled"
     JSON_FEATUREGROUP_FEATURE_HISTOGRAM_ENABLED = "featHistEnabled"
     JSON_FEATUREGROUP_FEATURE_CORRELATION_ENABLED = "featCorrEnabled"
-    JSON_FEATUREGROUP_CLUSTER_ANALYSIS_ENABLED = "clusterAnalysisEnabled"
     JSON_FEATUREGROUP_DESCRIPTIVE_STATISTICS_ENABLED = "descStatsEnabled"
     JSON_FEATUREGROUP_STATISTIC_COLUMNS = "statisticColumns"
-    JSON_FEATUREGROUP_NUM_BINS = "numBins"
-    JSON_FEATUREGROUP_NUM_CLUSTERS = "numClusters"
-    JSON_FEATUREGROUP_CORR_METHOD = "corrMethod"
 
     JSON_ONLINE_FEATUREGROUP_ID = "id"
     JSON_ONLINE_FEATUREGROUP_DB = "dbName"
@@ -427,6 +408,7 @@ class REST_CONFIG:
 
     JSON_FEATURE_NAME = "name"
     JSON_FEATURE_TYPE = "type"
+    JSON_FEATURE_INDEX = "index"
     JSON_FEATURE_DESCRIPTION = "description"
     JSON_FEATURE_PRIMARY = "primary"
     JSON_FEATURE_PARTITION = "partition"
@@ -450,12 +432,7 @@ class REST_CONFIG:
     JSON_TRAINING_DATASET_CREATOR = "creator"
     JSON_TRAINING_DATASET_CREATED = "created"
     JSON_TRAINING_DATASET_DESCRIPTION = "description"
-    JSON_TRAINING_DATASET_FEATURE_CORRELATION = "featureCorrelationMatrix"
-    JSON_TRAINING_DATASET_FEATURES_HISTOGRAM = "featuresHistogram"
-    JSON_TRAINING_DATASET_CLUSTERS = "clusterAnalysis"
-    JSON_TRAINING_DATASET_DESC_STATS = "descriptiveStatistics"
     JSON_TRAINING_DATASET_JOBNAME = "jobName"
-    JSON_TRAINING_DATASET_UPDATE_STATS = "updateStats"
     JSON_TRAINING_DATASET_INODE_ID = "inodeId"
     JSON_TRAINING_DATASET_FEATURES = "features"
     JSON_TRAINING_DATASET_JOBS = "jobs"
@@ -504,6 +481,7 @@ class REST_CONFIG:
     HOPSWORKS_TOPICS_RESOURCE = "topics"
     HOPSWORKS_SUBJECTS_RESOURCE = "subjects"
 
+    HOPSWORKS_AS_SHARED = "asShared"
     HOPSWORKS_PROJECT_RESOURCE = "project"
     HOPSWORKS_PROJECT_INFO_RESOURCE = "getProjectInfo"
     HOPSWORKS_JOBS_RESOURCE = "jobs"
@@ -518,29 +496,6 @@ class REST_CONFIG:
     HOPSWORKS_ELASTIC_RESOURCE = "elastic"
     HOPSWORKS_ELASTIC_JWT_RESOURCE = "jwt"
 
-    JSON_DESCRIPTIVE_STATS_FEATURE_NAME= "featureName"
-    JSON_DESCRIPTIVE_STATS_METRIC_VALUES= "metricValues"
-    JSON_DESCRIPTIVE_STATS= "descriptiveStats"
-
-    JSON_CLUSTERING_ANALYSIS_DATA_POINT_NAME = "datapointName"
-    JSON_CLUSTERING_ANALYSIS_FIRST_DIMENSION = "firstDimension"
-    JSON_CLUSTERING_ANALYSIS_SECOND_DIMENSION = "secondDimension"
-    JSON_CLUSTERING_ANALYSIS_CLUSTER = "cluster"
-    JSON_CLUSTERING_ANALYSIS_CLUSTERS = "clusters"
-    JSON_CLUSTERING_ANALYSIS_DATA_POINTS = "dataPoints"
-
-    JSON_HISTOGRAM_FREQUENCY = "frequency"
-    JSON_HISTOGRAM_BIN = "bin"
-    JSON_HISTOGRAM_FEATURE_NAME = "featureName"
-    JSON_HISTOGRAM_FREQUENCY_DISTRIBUTION = "frequencyDistribution"
-    JSON_HISTOGRAM_FEATURE_DISTRIBUTIONS = "featureDistributions"
-
-    JSON_CORRELATION_FEATURE_NAME = "featureName"
-    JSON_CORRELATION = "correlation"
-    JSON_CORRELATION_VALUES = "correlationValues"
-
-    JSON_FEATURE_CORRELATIONS = "featureCorrelations"
-
     JSON_ERROR_CODE = "errorCode"
     JSON_ERROR_MSG = "errorMsg"
     JSON_USR_MSG = "usrMsg"
@@ -567,6 +522,19 @@ class REST_CONFIG:
     JSON_KAFKA_NUM_PARTITIONS = "numOfPartitions"
     JSON_KAFKA_NUM_REPLICAS = "numOfReplicas"
 
+    HOPSWORKS_CLOUD_RESOURCE = "cloud"
+    HOPSWORKS_AWS_CLOUD_SESSION_TOKEN_RESOURCE = "aws/session-token"
+    HOPSWORKS_CLOUD_ROLE_MAPPINGS_RESOURCE = "role-mappings"
+    HOPSWORKS_CLOUD_SESSION_TOKEN_RESOURCE_QUERY_ROLE = "roleARN"
+    HOPSWORKS_CLOUD_SESSION_TOKEN_RESOURCE_QUERY_SESSION = "roleSessionName"
+    HOPSWORKS_CLOUD_SESSION_TOKEN_RESOURCE_QUERY_SESSION_DURATION = "durationSeconds"
+
+    JSON_ACCESS_KEY_ID = "accessKeyId"
+    JSON_SECRET_KEY_ID = "secretAccessKey"
+    JSON_SESSION_TOKEN_ID = "sessionToken"
+    JSON_ARRAY_ITEMS = "items"
+    JSON_CLOUD_ROLE = "cloudRole"
+
 
 class DELIMITERS:
     """
@@ -591,7 +559,13 @@ class S3_CONFIG:
     S3_FILE_PREFIX = "s3a://"
     S3_ACCESS_KEY_ENV = "fs.s3a.access.key"
     S3_SECRET_KEY_ENV = "fs.s3a.secret.key"
+    S3_SESSION_KEY_ENV = "fs.s3a.session.token"
+    S3_CREDENTIAL_PROVIDER_ENV = "fs.s3a.aws.credentials.provider"
+    S3_TEMPORARY_CREDENTIAL_PROVIDER = "org.apache.hadoop.fs.s3a.TemporaryAWSCredentialsProvider"
     S3_TRAINING_DATASETS_FOLDER = "TRAINING_DATASETS"
+    AWS_ACCESS_KEY_ID_ENV = "AWS_ACCESS_KEY_ID"
+    AWS_SECRET_ACCESS_KEY_ENV = "AWS_SECRET_ACCESS_KEY"
+    AWS_SESSION_TOKEN_ENV = "AWS_SESSION_TOKEN"
 
 class AWS:
     DEFAULT_REGION = 'default'
