@@ -12,12 +12,12 @@ import os
 import six
 
 
-def _run(sc, map_fun, run_id, args_dict=None, local_logdir=False, name="no-name"):
+def _run(sc, train_fn, run_id, args_dict=None, local_logdir=False, name="no-name"):
     """
 
     Args:
         sc:
-        map_fun:
+        train_fn:
         args_dict:
         local_logdir:
         name:
@@ -44,7 +44,7 @@ def _run(sc, map_fun, run_id, args_dict=None, local_logdir=False, name="no-name"
     nodeRDD = sc.parallelize(range(num_executions), num_executions)
 
     #Force execution on executor, since GPU is located on executor
-    nodeRDD.foreachPartition(_prepare_func(app_id, run_id, map_fun, args_dict, local_logdir))
+    nodeRDD.foreachPartition(_prepare_func(app_id, run_id, train_fn, args_dict, local_logdir))
 
     print('Finished Experiment \n')
 
@@ -58,8 +58,8 @@ def _run(sc, map_fun, run_id, args_dict=None, local_logdir=False, name="no-name"
         else:
             return experiment_utils._get_logdir(app_id, run_id), None
     elif num_executions == 1:
-        arg_count = six.get_function_code(map_fun).co_argcount
-        arg_names = six.get_function_code(map_fun).co_varnames
+        arg_count = six.get_function_code(train_fn).co_argcount
+        arg_names = six.get_function_code(train_fn).co_varnames
         argIndex = 0
         param_string = ''
         while arg_count > 0:
@@ -80,13 +80,13 @@ def _run(sc, map_fun, run_id, args_dict=None, local_logdir=False, name="no-name"
         return experiment_utils._get_logdir(app_id, run_id), None
 
 #Helper to put Spark required parameter iter in function signature
-def _prepare_func(app_id, run_id, map_fun, args_dict, local_logdir):
+def _prepare_func(app_id, run_id, train_fn, args_dict, local_logdir):
     """
 
     Args:
         app_id:
         run_id:
-        map_fun:
+        train_fn:
         args_dict:
         local_logdir:
 
@@ -119,7 +119,7 @@ def _prepare_func(app_id, run_id, map_fun, args_dict, local_logdir):
         try:
             #Arguments
             if args_dict:
-                param_string, params, args = experiment_utils.build_parameters(map_fun, executor_num, args_dict)
+                param_string, params, args = experiment_utils.build_parameters(train_fn, executor_num, args_dict)
                 hdfs_exec_logdir, hdfs_appid_logdir = experiment_utils._create_experiment_subdirectories(app_id, run_id, param_string, 'grid_search', params=params)
                 logfile = experiment_utils._init_logger(hdfs_exec_logdir)
                 tb_hdfs_path, tb_pid = tensorboard._register(hdfs_exec_logdir, hdfs_appid_logdir, executor_num, local_logdir=local_logdir)
@@ -127,7 +127,7 @@ def _prepare_func(app_id, run_id, map_fun, args_dict, local_logdir):
                 print('-------------------------------------------------------')
                 print('Started running task ' + param_string)
                 task_start = time.time()
-                retval = map_fun(*args)
+                retval = train_fn(*args)
                 task_end = time.time()
                 experiment_utils._handle_return_simple(retval, hdfs_exec_logdir, logfile)
                 time_str = 'Finished task ' + param_string + ' - took ' + experiment_utils._time_diff(task_start, task_end)
@@ -140,7 +140,7 @@ def _prepare_func(app_id, run_id, map_fun, args_dict, local_logdir):
                 print('-------------------------------------------------------')
                 print('Started running task')
                 task_start = time.time()
-                retval = map_fun()
+                retval = train_fn()
                 task_end = time.time()
                 experiment_utils._handle_return_simple(retval, hdfs_exec_logdir, logfile)
                 time_str = 'Finished task - took ' + experiment_utils._time_diff(task_start, task_end)
