@@ -1,5 +1,6 @@
 from hops import constants
 from hops.featurestore_impl.dao.common.featurestore_entity import FeaturestoreEntity
+from hops.featurestore_impl.dao.features.training_dataset_feature import TrainingDatasetFeature
 
 
 class TrainingDataset(FeaturestoreEntity):
@@ -27,3 +28,17 @@ class TrainingDataset(FeaturestoreEntity):
         self.location = training_dataset_json[constants.REST_CONFIG.JSON_FEATURESTORE_LOCATION]
         self.connector_id = training_dataset_json[constants.REST_CONFIG.JSON_TRAINING_DATASET_CONNECTOR_ID]
         self.connector_name = training_dataset_json[constants.REST_CONFIG.JSON_TRAINING_DATASET_CONNECTOR_NAME]
+
+
+    def _parse_features(self, features_json):
+        """
+        Parses a list of features in JSON format into a list of Feature objects
+
+        Args:
+            :features_json: json representation of the list of features
+
+        Returns:
+            a list of Feature objects
+        """
+        return list(map(lambda feature_json: TrainingDatasetFeature(feature_json), features_json))
+
