@@ -2,6 +2,7 @@ from hops import constants
 from hops.featurestore_impl.dao.common.featurestore_entity import FeaturestoreEntity
 from hops.featurestore_impl.dao.featuregroups.cached_featuregroup import CachedFeaturegroup
 from hops.featurestore_impl.dao.featuregroups.on_demand_featuregroup import OnDemandFeaturegroup
+from hops.featurestore_impl.dao.features.feature import Feature
 
 
 class Featuregroup(FeaturestoreEntity):
@@ -33,12 +34,7 @@ class Featuregroup(FeaturestoreEntity):
             constants.REST_CONFIG.JSON_FEATUREGROUP_DESCRIPTIVE_STATISTICS_ENABLED]
         self.feat_corr_enabled = featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_FEATURE_CORRELATION_ENABLED]
         self.feat_hist_enabled = featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_FEATURE_HISTOGRAM_ENABLED]
-        self.cluster_analysis_enabled = featuregroup_json[
-            constants.REST_CONFIG.JSON_FEATUREGROUP_CLUSTER_ANALYSIS_ENABLED]
         self.stat_columns = featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_STATISTIC_COLUMNS]
-        self.num_bins = featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_NUM_BINS]
-        self.num_clusters = featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_NUM_CLUSTERS]
-        self.corr_method = featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_CORR_METHOD]
 
         if(self.featuregroup_type == "onDemandFeaturegroupDTO"):
             self.on_demand_featuregroup = OnDemandFeaturegroup(featuregroup_json)
@@ -46,6 +42,19 @@ class Featuregroup(FeaturestoreEntity):
             self.cached_featuregroup = CachedFeaturegroup(featuregroup_json)
 
 
+    def _parse_features(self, features_json):
+        """
+        Parses a list of features in JSON format into a list of Feature objects
+
+        Args:
+            :features_json: json representation of the list of features
+
+        Returns:
+            a list of Feature objects
+        """
+        return list(map(lambda feature_json: Feature(feature_json), features_json))
+
+
     def __lt__(self, other):
         return self.name.__lt__(other.name)
 
