@@ -12,6 +12,6 @@ class OnDemandFeaturegroup():
         Args:
             :on_demand_featuregroup_json: JSON representation of the featuregroup, returned from Hopsworks REST API
         """
-        self.jdbc_connector_id = on_demand_featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_JDBC_CONNECTOR_ID]
-        self.jdbc_connector_name = on_demand_featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_JDBC_CONNECTOR_NAME]
+        self.jdbc_connector_id = on_demand_featuregroup_json['storageConnector']['id']
+        self.jdbc_connector_name = on_demand_featuregroup_json['storageConnector']['name']
         self.query = on_demand_featuregroup_json[constants.REST_CONFIG.JSON_FEATUREGROUP_ON_DEMAND_QUERY]
\ No newline at end of file
