@@ -19,12 +19,13 @@ import ntpath
 import importlib
 
 # Compatibility with SageMaker
+pydoop_available = True
 try:
     import pydoop.hdfs as hdfs
     import pydoop.hdfs.path as path
     import pydoop.hdfs.fs as hdfs_fs
 except:
-    pass
+    pydoop_available = False
 
 import re
 from xml.dom import minidom
@@ -32,33 +33,33 @@ from xml.dom import minidom
 tls_enabled = None
 webhdfs_address = None
 
+if pydoop_available: 
+    # Replace Pydoop split method to be able to support hopsfs:// schemes
+    class _HopsFSPathSplitter(hdfs.path._HdfsPathSplitter):
+        @classmethod
+        def split(cls, hdfs_path, user):
+            if not hdfs_path:
+                cls.raise_bad_path(hdfs_path, "empty")
+            scheme, netloc, path = cls.parse(hdfs_path)
+            if not scheme:
+                scheme = "file" if hdfs_fs.default_is_local() else "hdfs"
+            if scheme == "hdfs" or scheme == "hopsfs":
+                if not path:
+                    cls.raise_bad_path(hdfs_path, "path part is empty")
+                if ":" in path:
+                    cls.raise_bad_path(
+                        hdfs_path, "':' not allowed outside netloc part"
+                    )
+                hostname, port = cls.split_netloc(netloc)
+                if not path.startswith("/"):
+                    path = "/user/%s/%s" % (user, path)
+            elif scheme == "file":
+                hostname, port, path = "", 0, netloc + path
+            else:
+                cls.raise_bad_path(hdfs_path, "unsupported scheme %r" % scheme)
+            return hostname, port, path
 
-# Replace Pydoop split method to be able to support hopsfs:// schemes
-class _HopsFSPathSplitter(hdfs.path._HdfsPathSplitter):
-    @classmethod
-    def split(cls, hdfs_path, user):
-        if not hdfs_path:
-            cls.raise_bad_path(hdfs_path, "empty")
-        scheme, netloc, path = cls.parse(hdfs_path)
-        if not scheme:
-            scheme = "file" if hdfs_fs.default_is_local() else "hdfs"
-        if scheme == "hdfs" or scheme == "hopsfs":
-            if not path:
-                cls.raise_bad_path(hdfs_path, "path part is empty")
-            if ":" in path:
-                cls.raise_bad_path(
-                    hdfs_path, "':' not allowed outside netloc part"
-                )
-            hostname, port = cls.split_netloc(netloc)
-            if not path.startswith("/"):
-                path = "/user/%s/%s" % (user, path)
-        elif scheme == "file":
-            hostname, port, path = "", 0, netloc + path
-        else:
-            cls.raise_bad_path(hdfs_path, "unsupported scheme %r" % scheme)
-        return hostname, port, path
-
-hdfs.path._HdfsPathSplitter = _HopsFSPathSplitter
+    hdfs.path._HdfsPathSplitter = _HopsFSPathSplitter
 
 def get_plain_path(abs_path):
     """
@@ -86,7 +87,6 @@ def project_id():
     """
     return os.environ[constants.ENV_VARIABLES.HOPSWORKS_PROJECT_ID_ENV_VAR]
 
-
 def project_user():
     """
     Gets the project username ("project__user") from environment variables
@@ -127,7 +127,7 @@ def project_path(project=None, exclude_nn_addr=False):
     >>> print("Project path: {}".format(project_path))
 
     Args:
-        :project_name: If this value is not specified, it will get the path to your project. If you need to path to another project, you can specify the name of the project as a string.
+        :project: If this value is not specified, it will get the path to your project. If you need to path to another project, you can specify the name of the project as a string.
 
     Returns:
         returns the project absolute path
